==> dse_2001.6-1.tar.gz: dse/dse1/man/eg1.DSE.data.Rd <==
\name{eg1.DSE.data}
\alias{eg1.DSE.data}
\alias{eg1.DSE.data.diff}
\alias{eg1.dat}

\title{Four Time Series used in Gilbert (1993)}

\description{

	Data is for Canada. 
	The series start in March 1961 (April 1961 for eg1.DSE.data.diff)
	and end in June 1991, giving 364  
	observations on each variable (363 for eg1.DSE.data.diff).

	The input series is 90-day interest rates (R90) in both eg1.DSE.data and
	eg1.DSE.data.diff.

	The output series are M1, GDP lagged two months, and CPI. 
	M1, GDP and CPI were all seasonally adjusted data. 
	These are not transformed in eg1.DSE.data and first difference of
	logs in eg1.DSE.data.diff.

	GDP is lagged because it is not available on as timely a basis. 
	(The data was used in an example where the intent was to build 
	a model for timely monitoring.)

	The Statistics Canada series identifiers are B14017, B1627, I37026,
	and B820200.
	
	The data for M1 (B1627) were taken prior to revisions made in 
	December 1993.
	
	The file eg1.dat contains the same data as eg1.DSE.data in a simple 
	ASCII file. 
}


\usage{
	data(eg1.DSE.data)
	data(eg1.DSE.data.diff)
}

\arguments{
	\item{input series 1}{R90}
	\item{output series 1}{M1}
	\item{output series 2}{GDP lagged two months}
	\item{output series 3}{CPI}
}

\format{
	The objects eg1.DSE.data and eg1.DSE.data.diff are TSdata objects.
	The file eg1.dat is an ASCII file with 5 columns, the first enumerating
	the observations, the second giving the input series, and the third to
	fifth giving the output series. 
	The input series name  is  "R90" and the output series names are
	"M1", "GDPl2" and "CPI".
}

\source{
	\emph{Statistics Canada,} 
	\emph{Bank of Canada.}
}

\references{
	Gilbert, P.D. 1993. "State Space and ARMA Models: An Overview of the 
	Equivalence." Working Paper 93-4, Bank of Canada. Also available at 
	\url{www.bank-banque-canada.ca/pgilbert}.

}

\seealso{
	\code{\link{TSdata}}
}
\keyword{datasets}

==> dse_2003.6-1.tar.gz: dse/dse1/man/eg1.DSE.data.Rd <==
\name{eg1.DSE.data}
\alias{eg1.DSE.data}
\alias{eg1.DSE.data.diff}
\alias{eg1.dat}

\title{Four Time Series used in Gilbert (1993)}

\description{

	Data is for Canada. 
	The series start in March 1961 (April 1961 for eg1.DSE.data.diff)
	and end in June 1991, giving 364  
	observations on each variable (363 for eg1.DSE.data.diff).

	The input series is 90-day interest rates (R90) in both eg1.DSE.data and
	eg1.DSE.data.diff.

	The output series are M1, GDP lagged two months, and CPI. 
	M1, GDP and CPI were all seasonally adjusted data. 
	These are not transformed in eg1.DSE.data and first difference of
	logs in eg1.DSE.data.diff.

	GDP is lagged because it is not available on as timely a basis. 
	(The data was used in an example where the intent was to build 
	a model for timely monitoring.)

	The Statistics Canada series identifiers are B14017, B1627, I37026,
	and B820200.
	
	The data for M1 (B1627) were taken prior to revisions made in 
	December 1993.
	
	The file eg1.dat contains the same data as eg1.DSE.data in a simple 
	ASCII file. 
}


\usage{
	data(eg1.DSE.data)
	data(eg1.DSE.data.diff)
}

\format{
	The objects eg1.DSE.data and eg1.DSE.data.diff are TSdata objects.
	The file eg1.dat is an ASCII file with 5 columns, the first enumerating
	the observations, the second giving the input series, and the third to
	fifth giving the output series. 
	The input series name  is  "R90" and the output series names are
	"M1", "GDPl2" and "CPI". GDPl2 is GDP lagged two months
}

\source{
	\emph{Statistics Canada,} 
	\emph{Bank of Canada.}
}

\references{
	Gilbert, P.D. 1993. "State Space and ARMA Models: An Overview of the 
	Equivalence." Working Paper 93-4, Bank of Canada. Also available at 
	\url{www.bank-banque-canada.ca/pgilbert}.

}

\seealso{
	\code{\link{TSdata}}
}
\keyword{datasets}
